# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UpdateSheetProtectedDimensionReqRequestsEditorsDelEditors(object):
    member_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户类型，支持userId,openId,unionId
    member_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户类型对应的用户ID


@attr.s
class UpdateSheetProtectedDimensionReqRequestsEditorsAddEditors(object):
    member_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户类型，支持userId,openId,unionId
    member_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户类型对应的用户ID


@attr.s
class UpdateSheetProtectedDimensionReqRequestsEditors(object):
    add_editors: UpdateSheetProtectedDimensionReqRequestsEditorsAddEditors = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 需要增加的用户的列表，用户需要有文档的编辑权限
    del_editors: UpdateSheetProtectedDimensionReqRequestsEditorsDelEditors = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 需要删除的用户的列表


@attr.s
class UpdateSheetProtectedDimensionReqRequestsDimension(object):
    sheet_id: str = attr.ib(default="", metadata={"req_type": "json"})  # sheetId
    start_index: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 保护行列起始下标，下标从1开始
    end_index: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 保护行列终止下标，下标从1开始
    major_dimension: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 保护范围ID对应的保护范围的维度，COLUMNS为保护列，ROWS为保护行


@attr.s
class UpdateSheetProtectedDimensionReqRequests(object):
    protect_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 保护范围ID，可以通过[获取表格元数据](https://open.feishu.cn/document/ukTMukTMukTM/uETMzUjLxEzM14SMxMTN) 接口获取
    dimension: UpdateSheetProtectedDimensionReqRequestsDimension = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 行列保护信息
    editors: UpdateSheetProtectedDimensionReqRequestsEditors = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 可编辑保护范围的用户
    lock_info: str = attr.ib(default="", metadata={"req_type": "json"})  # 保护说明


@attr.s
class UpdateSheetProtectedDimensionReq(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # sheet 的 token，获取方式见[在线表格开发指南](https://open.feishu.cn/document/ukTMukTMukTM/uATMzUjLwEzM14CMxMTN/overview)
    requests: UpdateSheetProtectedDimensionReqRequests = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 请求


@attr.s
class UpdateSheetProtectedDimensionRespReplyEditorsDelEditor(object):
    member_type: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户类型
    member_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户类型对应的用户ID


@attr.s
class UpdateSheetProtectedDimensionRespReplyEditorsAddEditor(object):
    member_type: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户类型
    member_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户类型对应的用户ID


@attr.s
class UpdateSheetProtectedDimensionRespReplyEditors(object):
    add_editors: typing.List[
        UpdateSheetProtectedDimensionRespReplyEditorsAddEditor
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 成功增加的用户的列表
    del_editors: typing.List[
        UpdateSheetProtectedDimensionRespReplyEditorsDelEditor
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 成功删除的用户的列表


@attr.s
class UpdateSheetProtectedDimensionRespReplyDimension(object):
    sheet_id: str = attr.ib(default="", metadata={"req_type": "json"})  # sheetId
    start_index: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 保护行列起始下标，下标从1开始
    end_index: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 保护行列终止下标，下标从1开始
    major_dimension: str = attr.ib(default="", metadata={"req_type": "json"})  # 保护范围的维度


@attr.s
class UpdateSheetProtectedDimensionRespReply(object):
    sheet_id: str = attr.ib(default="", metadata={"req_type": "json"})  # sheet的id
    dimension: UpdateSheetProtectedDimensionRespReplyDimension = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 成功修改的保护行列信息
    editors: UpdateSheetProtectedDimensionRespReplyEditors = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 可编辑保护范围的用户
    lock_info: str = attr.ib(default="", metadata={"req_type": "json"})  # 成功修改的保护说明


@attr.s
class UpdateSheetProtectedDimensionResp(object):
    replies: typing.List[UpdateSheetProtectedDimensionRespReply] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 响应


def _gen_update_sheet_protected_dimension_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UpdateSheetProtectedDimensionResp,
        scope="Drive",
        api="UpdateSheetProtectedDimension",
        method="POST",
        url="https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/:spreadsheetToken/protected_range_batch_update",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class BatchGetMeetingRoomRoomIDReq(object):
    custom_room_ids: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 用于查询指定会议室的租户自定义会议室ID


@attr.s
class BatchGetMeetingRoomRoomIDRespRoom(object):
    room_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 会议室 ID
    custom_room_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 租户自定义会议室 ID


@attr.s
class BatchGetMeetingRoomRoomIDResp(object):
    rooms: BatchGetMeetingRoomRoomIDRespRoom = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 会议室列表


def _gen_batch_get_meeting_room_room_id_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=BatchGetMeetingRoomRoomIDResp,
        scope="MeetingRoom",
        api="BatchGetMeetingRoomRoomID",
        method="GET",
        url="https://open.feishu.cn/open-apis/meeting_room/room/batch_get_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UpdateMeetingRoomRoomReq(object):
    room_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 要更新的会议室ID
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 会议室名称
    capacity: int = attr.ib(default=0, metadata={"req_type": "json"})  # 容量
    custom_room_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 租户自定义会议室ID


@attr.s
class UpdateMeetingRoomRoomResp(object):
    pass


def _gen_update_meeting_room_room_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UpdateMeetingRoomRoomResp,
        scope="MeetingRoom",
        api="UpdateMeetingRoomRoom",
        method="POST",
        url="https://open.feishu.cn/open-apis/meeting_room/room/update",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetTaskCollaboratorListReqUserIDType(object):
    pass


@attr.s
class GetTaskCollaboratorListReq(object):
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 分页大小, 示例值：50, 最大值：`50`
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 分页标记，第一次请求不填，表示从头开始遍历；分页查询结果还有更多项时会同时返回新的 page_token，下次遍历可采用该 page_token 获取查询结果, 示例值："「上次返回的page_token」"
    user_id_type: GetTaskCollaboratorListReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`,, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    task_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 任务 ID, 示例值："0d38e26e-190a-49e9-93a2-35067763ed1f"


@attr.s
class GetTaskCollaboratorListRespItem(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 任务协作者的 ID


@attr.s
class GetTaskCollaboratorListResp(object):
    items: typing.List[GetTaskCollaboratorListRespItem] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 返回的协作者列表
    page_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 分页标记，当 has_more 为 true 时，会同时返回新的 page_token，否则不返回 page_token
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否还有更多项


def _gen_get_task_collaborator_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetTaskCollaboratorListResp,
        scope="Task",
        api="GetTaskCollaboratorList",
        method="GET",
        url="https://open.feishu.cn/open-apis/task/v1/tasks/:task_id/collaborators",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetBitableRecordListReq(object):
    view_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 视图 id, 如filter或sort有值, view_id会被忽略, 示例值："vewqhz51lk"
    filter: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # filter, 不超过2000个字符, 不支持对带特殊字段(关联和公式)的表的使用, 示例值："AND(CurrentValue.[身高]>180, CurrentValue.[体重]>150)"
    sort: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # sort, 不超过1000字符, 不支持对带特殊字段(关联和公式)的表的使用, 示例值："["字段1 DESC","字段2 ASC"]"
    field_names: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # field_names, 示例值："["字段1"]"
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 分页标记，第一次请求不填，表示从头开始遍历；分页查询结果还有更多项时会同时返回新的 page_token，下次遍历可采用该 page_token 获取查询结果, 示例值："recn0hoyXL"
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 分页大小, 示例值：10, 最大值：`100`
    app_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # bitable app token, 示例值："bascnCMII2ORej2RItqpZZUNMIe"
    table_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # table id, 示例值："tblxI2tWaxP5dG7p"


@attr.s
class GetBitableRecordListRespItemFieldsValue(object):
    pass


@attr.s
class GetBitableRecordListRespItemFields(object):
    key: str = attr.ib(default="", metadata={"req_type": "json"})  # 字段名
    value: typing.Any = attr.ib(default=None, metadata={"req_type": "json"})  # 内容


@attr.s
class GetBitableRecordListRespItem(object):
    record_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 记录 id
    fields: GetBitableRecordListRespItemFields = attr.ib(
        factory=lambda: GetBitableRecordListRespItemFields(),
        metadata={"req_type": "json"},
    )  # 记录字段


@attr.s
class GetBitableRecordListResp(object):
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否还有更多项
    page_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 分页标记，当 has_more 为 true 时，会同时返回新的 page_token，否则不返回 page_token
    items: typing.List[GetBitableRecordListRespItem] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 记录信息


def _gen_get_bitable_record_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetBitableRecordListResp,
        scope="Bitable",
        api="GetBitableRecordList",
        method="GET",
        url="https://open.feishu.cn/open-apis/bitable/v1/apps/:app_token/tables/:table_id/records",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetVCReserveActiveMeetingReq(object):
    with_participants: bool = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 是否需要参会人列表，默认为false, 示例值：false
    reserve_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 预约ID（预约的唯一标识）, 示例值："6911188411932033028"


@attr.s
class GetVCReserveActiveMeetingRespMeetingAbility(object):
    use_video: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否使用视频
    use_audio: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否使用音频
    use_share_screen: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否使用共享屏幕
    use_follow_screen: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否使用妙享（magic share）
    use_recording: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否使用录制
    use_pstn: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否使用PSTN


@attr.s
class GetVCReserveActiveMeetingRespMeetingParticipant(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户ID
    user_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 用户类型, 可选值有: `1`：lark用户, `2`：rooms用户, `3`：文档用户, `4`：neo单品用户, `5`：neo单品游客用户, `6`：pstn用户, `7`：sip用户
    is_host: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否为主持人
    is_cohost: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否为联席主持人
    is_external: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否为外部参会人
    status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 参会人状态, 可选值有: `1`：呼叫中, `2`：在会中, `3`：正在响铃, `4`：不在会中或已经离开会议


@attr.s
class GetVCReserveActiveMeetingRespMeetingHostUser(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户ID
    user_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 用户类型, 可选值有: `1`：lark用户, `2`：rooms用户, `3`：文档用户, `4`：neo单品用户, `5`：neo单品游客用户, `6`：pstn用户, `7`：sip用户


@attr.s
class GetVCReserveActiveMeetingRespMeeting(object):
    id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 会议ID（视频会议的唯一标识，视频会议开始后才会产生）
    topic: str = attr.ib(default="", metadata={"req_type": "json"})  # 会议主题
    url: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 会议链接（飞书用户可通过点击会议链接快捷入会）
    create_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 会议创建时间（unix时间，单位sec）
    start_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 会议开始时间（unix时间，单位sec）
    end_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 会议结束时间（unix时间，单位sec）
    host_user: GetVCReserveActiveMeetingRespMeetingHostUser = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 主持人
    status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 会议状态, 可选值有: `1`：会议呼叫中, `2`：会议进行中, `3`：会议已结束
    participant_count: str = attr.ib(default="", metadata={"req_type": "json"})  # 参会人数
    participants: typing.List[
        GetVCReserveActiveMeetingRespMeetingParticipant
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 参会人列表
    ability: GetVCReserveActiveMeetingRespMeetingAbility = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 会中使用的能力


@attr.s
class GetVCReserveActiveMeetingResp(object):
    meeting: GetVCReserveActiveMeetingRespMeeting = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 会议数据


def _gen_get_vc_reserve_active_meeting_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetVCReserveActiveMeetingResp,
        scope="VC",
        api="GetVCReserveActiveMeeting",
        method="GET",
        url="https://open.feishu.cn/open-apis/vc/v1/reserves/:reserve_id/get_active_meeting",
        body=request,
        method_option=_new_method_option(options),
        need_user_access_token=True,
    )
